#include "stdafx.h"
#include "NeMessenger.h"
#include "LayeredDlg.h"

#define LDLG_TITLE_POS_X		18
#define LDLG_TITLE_POS_Y		24
#define LDLG_MSG_POS_X			18
#define LDLG_MSG_POS_Y			46

IMPLEMENT_DYNAMIC(CLayeredDlg, CDialog)

CLayeredDlg::CLayeredDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CLayeredDlg::IDD, pParent)
{
	m_bShowTitle = TRUE;
	m_pImgBG = NULL;
	m_strTitle = _T("");
	m_strMsg = _T("");
	m_rtTitle.SetRectEmpty();
	m_rtMsg.SetRectEmpty();
}

CLayeredDlg::~CLayeredDlg()
{
	SAFE_DELETE(m_pImgBG);
}

void CLayeredDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
}


BEGIN_MESSAGE_MAP(CLayeredDlg, CDialog)
	ON_WM_PAINT()
	ON_WM_KILLFOCUS()
	ON_WM_CREATE()
	ON_WM_SIZE()
END_MESSAGE_MAP()


BOOL CLayeredDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	SetWindowLong(this->GetSafeHwnd(), GWL_EXSTYLE, GetWindowLong(this->GetSafeHwnd(), GWL_EXSTYLE) | WS_EX_LAYERED);
	SetLayeredWindowAttributes(RGB(0, 0, 0), 0, LWA_COLORKEY); 
	SetWindowPos(&wndTopMost, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE);

	return TRUE;  // return TRUE unless you set the focus to a control
	// : OCX Ӽ  FALSE ȯؾ մϴ.
}

void CLayeredDlg::OnPaint()
{
	CPaintDC dc(this); // device context for painting

	PAINTSTRUCT ps = dc.m_ps;
	int psWidth = ps.rcPaint.right - ps.rcPaint.left;
	int psHeight = ps.rcPaint.bottom - ps.rcPaint.top;

	int nPX = ps.rcPaint.left;
	int nPY = ps.rcPaint.top;

	CRect rtPS(nPX, nPY, nPX + psWidth, nPY + psHeight);

	CRect rt(0, 0, 0, 0);
	GetClientRect(&rt);
	//int nWndWidth = rt.Width();
	//int nWndHeight = rt.Height();

	HDC hdc = dc.GetSafeHdc();

	HDC	hdcMemory = CreateCompatibleDC(hdc);

	if (hdcMemory == NULL)
		return;

	HBITMAP hbmpMem = CreateCompatibleBitmap(hdc, psWidth, psHeight);

	HGDIOBJ hbmpOld = ::SelectObject(hdcMemory,  hbmpMem);

	Graphics graph(hdcMemory);

	if (hbmpMem)
	{
		graph.SetPageUnit(UnitPixel);

		ImageAttributes ImgAttr;

		if (m_pImgBG)
			DrawImageToDest(&graph, m_pImgBG, &rtPS, &rt, &ImgAttr);
		else
		{
			SolidBrush brush(Color(0, 255, 255, 255));
			Pen pen(Color(255, 0, 0, 0), 1);
			graph.DrawRectangle(&pen, 0, 0, psWidth, psHeight);
			graph.FillRectangle(&brush, 0, 0, psWidth, psHeight);
		}

		//  ĥϱ  AntiAlias ϸ   ϰ ܻ Ƿ  ĥ  Ѵ.
		graph.SetSmoothingMode(SmoothingModeAntiAlias);
		graph.SetTextRenderingHint(TextRenderingHintClearTypeGridFit);

		if (m_bShowTitle)
		{
			DrawTextToDest2(&graph, m_strTitle, &rtPS, &(m_rtTitle), g_defaultFontFaceName, 9, StringAlignmentNear, FontStyleBold, Color(255, 5, 140, 255));
			DrawTextToDest2(&graph, m_strMsg, &rtPS, &(m_rtMsg), g_defaultFontFaceName, 8, StringAlignmentNear, FontStyleRegular, Color(255, 102, 102, 102));
		}
		else
		{
			CString strWorkStatus;
			CString strWorkStatusDay;
			AfxExtractSubString(strWorkStatus , m_strMsg, 0, ':');
			AfxExtractSubString(strWorkStatusDay , m_strMsg, 1, ':');
			DrawTextToDest2(&graph, strWorkStatus, &rtPS, &(m_rtMsg), g_defaultFontFaceName, 10, StringAlignmentCenter, FontStyleBold, Color(255, 102, 102, 102));
			DrawTextToDest2(&graph, L"\n" + strWorkStatusDay, &rtPS, &(m_rtMsg), g_defaultFontFaceName, 10, StringAlignmentCenter, FontStyleRegular, Color(255, 102, 102, 102));
		}

		BitBlt(dc.GetSafeHdc(), nPX, nPY, psWidth, psHeight, hdcMemory, 0, 0, SRCCOPY);

		::SelectObject(hdcMemory, hbmpOld);
		::DeleteObject(hbmpMem);
	}

	::DeleteDC(hdcMemory);
}

void CLayeredDlg::SetImgBGPath(CString strFileName)
{
	if (strFileName.IsEmpty())
		return;

	SAFE_DELETE(m_pImgBG);
	m_pImgBG = new Image(GetImagePath(strFileName));
}

CString CLayeredDlg::GetImagePath( CString strFileName )
{
	CString strImgPath = _T(""), strImgDir = _T("");
	strImgDir = GetAppImgDir();
	strImgPath.Format(_T("%s\\%s"), strImgDir, strFileName);

	return strImgPath;
}

void CLayeredDlg::OnKillFocus(CWnd* pNewWnd)
{
	CDialog::OnKillFocus(pNewWnd);

	DestroyWindow();
}

int CLayeredDlg::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	if (CDialog::OnCreate(lpCreateStruct) == -1)
		return -1;

	if (m_pImgBG)
		MoveWindow(0, 0, m_pImgBG->GetWidth(), m_pImgBG->GetHeight());

	return 0;
}

void CLayeredDlg::SetTitleAndMessage(CString strTitle, CString strMsg)
{
	m_strTitle = strTitle;
	m_strMsg = strMsg;
}

void CLayeredDlg::OnSize(UINT nType, int cx, int cy)
{
	CDialog::OnSize(nType, cx, cy);

	if(m_bShowTitle)
	{
		m_rtTitle.SetRect(LDLG_TITLE_POS_X, LDLG_TITLE_POS_Y, cx, LDLG_TITLE_POS_Y + 16);
		m_rtMsg.SetRect(LDLG_MSG_POS_X, LDLG_MSG_POS_Y, cx, cy);
	}
	else
	{
		m_rtMsg.SetRect(0, LDLG_TITLE_POS_Y, cx, cy);
	}
}

void CLayeredDlg::SetNoTitleAndMessage( CString strMsg )
{
	m_bShowTitle =FALSE;
	m_strMsg = strMsg;
	
}

